@@ -39,16 +39,18 @@ ASYNC = "OpenFuncAsync"
 @click.option("--debug", envvar="DEBUG", is_flag=True)
 @click.option("--dry-run", envvar="DRY_RUN", is_flag=True)
 def _cli(target, source, signature_type, host, port, debug, dry_run):
-    ctx = parse_function_context()
-    port = ctx.port
-    if ctx.runtime == KNATIVE_FUNC:
+    ff = os.getenv("FUNC_CONTEXT", "")
+    if signature_type == "http" and ff == "":
         app = create_app(target, source, signature_type)
-    elif ctx.runtime == ASYNC:
-
-        signature_type = "of"
-        app = create_dapr_app(target, source, signature_type, ctx)
     else:
-        app = create_app(target, source, signature_type)
+        ctx = parse_function_context()
+        port = ctx.port
+        if ctx.runtime == KNATIVE_FUNC:
+            app = create_app(target, source, signature_type)
+        elif ctx.runtime == ASYNC:
+
+            signature_type = "of"
+            app = create_dapr_app(target, source, signature_type, ctx)
     if dry_run:
         click.echo("Function: {}".format(target))
         click.echo("URL: http://{}:{}/".format(host, port))
